PROGRAM QwkSplit;  {split up a QWK index file}
{
If there are too many messages in a particular QWK message echo, do this:

1) UnZip the QWK packet into an empty directory.
2) Run "qwksplit filename" where 'filename' is the name of the QWK index 
   file (###.NDX) that you want to split up.
3) Delete the NDX file that you just split.
4) ReZip the QWK packet.

I do this with the index file 147.NDX which is for the Fido Geneology echo.

The output from this program is: 001.NDX, 002.NDX, 003.NDX, etc.  If any
of these filenames already exist they are NOT written over. Instead, that
number is skipped.  When you read the QWK packet the messages that used
to be in the split-up echo now appear to be in echoes 1, 2, 3, etc. With
SLMR any replies I make to these messages are addressed to the original
echo.

By default, the output NDX files contain no more than 500 records.  To
change this, add a second command line parameter which is a numeric value.
For example, "qwksplit 147.ndx 750" limits each output NDX to 750 messages.

(c) 1994 by:
Bruce R. Clawson
8506 West Stickney Avenue
Wauwatosa, WI  53226-2811
}

uses Dos;

type
   BsFmt = array [0..3] of byte;
   IdxRec = record
      IdxLoc : BsFmt;
      IdxCnf : byte;
      end;

var
   SrceFile : file of IdxRec;
   DestFile : file of IdxRec;

function Exist (FileName : string): boolean;
var
   DirInfo : SearchRec;
begin
   Exist := false;
   findfirst (FileName,anyfile,DirInfo);
   if DosError = 0
      then Exist := true;
end;  {Function Exist}

procedure AskSrceName (var FileName : string);
begin
   writeln;
   write  ('Enter Source file name or @ to abort: ');
   readln (FileName);
   if FileName [1] = '@'
      then halt;
end;

procedure OpenSrce (var FileName : string);
begin
   if (paramstr (1) <> '')
      then FileName := paramstr (1)
      else AskSrceName (FileName);
   if not Exist (FileName)
      then repeat AskSrceName (FileName)
           until Exist (FileName);
   assign (SrceFile,FileName);
   reset  (SrceFile);
end;

procedure OpenDest (var DestName : string; FileNumber : integer);
var
   NewName : string;
begin
   repeat
      str (FileNumber:3, NewName);
      if NewName [1] = ' '
         then NewName [1] := '0';
      if NewName [2] = ' '
         then NewName [2] := '0';
      DestName := NewName + '.NDX';
      inc (FileNumber);
      until not Exist (DestName);
   assign  (DestFile,DestName);
   rewrite (DestFile);
end;

procedure CloseDest (FileName : string; var Count : longint);
begin
   writeln (Count,' lines output to ', FileName);
   close (DestFile);
   Count := 0;
end;

{-----MAIN PROGRAM-----}
var
   Counter, Limit : longint;
   SrceName, DestName : string;
   Buffer : IdxRec;
   FileNumber, ErrCode : integer;
begin
   if paramstr (2) = ''
      then Limit := 500
      else begin
           val (paramstr (2), Limit, ErrCode);
           if ErrCode <> 0
              then begin
                   writeln ('Invalid limit parameter; using 500 instead.');
                   Limit := 500;
                   end;
           end;
   FileNumber := 1;
   OpenSrce (SrceName);
   OpenDest (DestName, FileNumber);
   Counter := 0;
   while not eof (SrceFile) do
      begin
      read  (SrceFile, Buffer);
      write (DestFile, Buffer);
      inc (Counter);
      if Counter = Limit
         then begin
              CloseDest (DestName, Counter);
              OpenDest (DestName, FileNumber);
              end;
      end;
   close (SrceFile);
   CloseDest (DestName, Counter);
end.
